@@ -8,7 +8,7 @@ use Amazon::SQS::Simple::Base; # for constants
 use Amazon::SQS::Simple::Queue;
 use base qw(Exporter Amazon::SQS::Simple::Base);
 
-our $VERSION   = '2.04';
+our $VERSION   = '2.05';
 our @EXPORT_OK = qw( timestamp );
 
 sub GetQueue {
@@ -92,7 +92,7 @@ Service
     my $secret_key = 'bar'; # Your AWS Secret Key
     
     # Create an SQS object
-    my $sqs = new Amazon::SQS::Simple($access_key, $secret_key);
+    my $sqs = new Amazon::SQS::Simple(AWSAccessKeyId => $access_key, SecretKey => $secret_key);
 
     # Create a new queue
     my $q = $sqs->CreateQueue('queue_name');
@@ -115,6 +115,9 @@ Service
     # Delete the queue
     $q->Delete();
 
+    # Purge the queue
+    $q->Purge();
+
 =head1 INTRODUCTION
 
 Amazon::SQS::Simple is an OO API for the Amazon Simple Queue Service.
@@ -255,11 +258,12 @@ in release 0.9.
 James Neal provided the proxy support code in release 2.0
 Roland Walker provided support for the newer signature version in release 2.0
 Chris Jones provied the batch message code in release 2.0
-Glenn Fowler (among others) provided a patch for the subtle access bug surfaved by hash key randomisation, as well as some test cleanup code in 2.04
+Rusty Conover provided the V4 signature support in release 2.05
+
 =head1 AUTHOR
 
 Copyright 2007-2008 Simon Whitaker E<lt>swhitaker@cpan.orgE<gt>
-Copyright 2013 Mike (no relation) Whitaker E<lt>penfold@cpan.orgE<gt>
+Copyright 2013-2017 Mike (no relation) Whitaker E<lt>penfold@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
